summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_functions_text.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_functions_text.cc')
-rw-r--r--kspread/kspread_functions_text.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kspread/kspread_functions_text.cc b/kspread/kspread_functions_text.cc
index e61aff93..432bfc28 100644
--- a/kspread/kspread_functions_text.cc
+++ b/kspread/kspread_functions_text.cc
@@ -252,7 +252,7 @@ Value func_dollar (valVector args, ValueCalc *calc, FuncExtra *)
// do round, because formatMoney doesn't
value = floor (value * pow (10.0, precision) + 0.5) / pow (10.0, precision);
- KLocale *locale = calc->conv()->locale();
+ TDELocale *locale = calc->conv()->locale();
TQString s = locale->formatMoney (value, locale->currencySymbol(), precision);
return Value (s);
@@ -303,9 +303,9 @@ Value func_fixed (valVector args, ValueCalc *calc, FuncExtra *)
no_commas = calc->conv()->asBoolean (args[2]).asBoolean();
TQString result;
- KLocale *locale = calc->conv()->locale();
+ TDELocale *locale = calc->conv()->locale();
- // unfortunately, we can't just use KLocale::formatNumber because
+ // unfortunately, we can't just use TDELocale::formatNumber because
// * if decimals < 0, number is rounded
// * if no_commas is true, thousand separators shouldn't show up